@@ -1,13 +1,14 @@
 package Org::Document;
 
-our $DATE = '2016-10-02'; # DATE
-our $VERSION = '0.50'; # VERSION
+our $DATE = '2016-11-06'; # DATE
+our $VERSION = '0.51'; # VERSION
 
 use 5.010;
 use locale;
 use Log::Any::IfLOG '$log';
 use Moo;
 use experimental 'smartmatch';
+no if $] ge 5.021_006, warnings => "locale";
 extends 'Org::Element';
 
 use List::MoreUtils qw(firstidx);
@@ -23,6 +24,8 @@ has radio_targets           => (is => 'rw');
 
 has time_zone               => (is => 'rw');
 
+has ignore_unknown_settings => (is => 'rw');
+
 our $tags_re       = qr/:(?:[A-Za-z0-9_@#%]+:)+/;
 my  $ls_re         = qr/(?:(?<=[\015\012])|\A)/; # line start
 my  $le_re         = qr/(?:\R|\z)/;              # line end
@@ -82,8 +85,8 @@ my $block_elems_re = # top level elements
                      \R(?<block_end_indent>[ \t]*)
                      \#\+END_\k<block_name> $le_re) |
        (?<setting>   $ls_re (?<setting_indent>[ \t]*) \#\+
-                     (?<setting_name> \w+): [ \t]+
-                     (?<setting_raw_arg> [^\n]+) $le_re) |
+                     (?<setting_name> \w+): (?: [ \t]+
+                     (?<setting_raw_arg> [^\n]*))? $le_re) |
        (?<fixedw>    (?: $ls_re [ \t]* (?::[ ][^\n]* | :$) $le_re )+ ) |
        (?<comment>   $ls_re [ \t]*\#[^\n]*(?:\R\#[^\n]*)* (?:\R|\z)) |
        (?<headline>  $ls_re (?<h_bullet>\*+) [ \t]
@@ -802,7 +805,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.50 of Org::Document (from Perl distribution Org-Parser), released on 2016-10-02.
+This document describes version 0.51 of Org::Document (from Perl distribution Org-Parser), released on 2016-11-06.
 
 =head1 SYNOPSIS
 
@@ -854,6 +857,10 @@ List of radio target text.
 
 If set, will be passed to DateTime->new() (e.g. by L<Org::Element::Timestamp>).
 
+=head2 ignore_unknown_settings => bool
+
+If set to true, unknown settings will not cause a parse failure.
+
 =head1 METHODS
 
 =for Pod::Coverage BUILD
