@@ -1,7 +1,7 @@
 package Org::Parser;
 
-our $DATE = '2016-10-02'; # DATE
-our $VERSION = '0.50'; # VERSION
+our $DATE = '2016-11-06'; # DATE
+our $VERSION = '0.51'; # VERSION
 
 use 5.010001;
 use Moo;
@@ -33,7 +33,11 @@ sub parse {
         die "Invalid argument, please supply a ".
             "string|arrayref|coderef|filehandle\n";
     }
-    Org::Document->new(from_string=>$str, time_zone=>$opts->{time_zone});
+    Org::Document->new(
+        from_string=>$str,
+        time_zone=>$opts->{time_zone},
+        ignore_unknown_settings=>$opts->{ignore_unknown_settings},
+    );
 }
 
 sub parse_file {
@@ -104,7 +108,7 @@ Org::Parser - Parse Org documents
 
 =head1 VERSION
 
-This document describes version 0.50 of Org::Parser (from Perl distribution Org-Parser), released on 2016-10-02.
+This document describes version 0.51 of Org::Parser (from Perl distribution Org-Parser), released on 2016-11-06.
 
 =head1 SYNOPSIS
 
